.. _contributor guide:

*****************
Contributor Guide
*****************

Thank you for your interest in contributing to PlasmaPy! |:sparkles:|
The future of the project depends on people like you, so we deeply
appreciate it! |:seedling:|

Please feel free to reach out to us in PlasmaPy's |Matrix chat room| or
during PlasmaPy's weekly |office hours|. The PlasmaPy community abides
by the :ref:`Contributor Covenant Code of Conduct
<plasmapy-code-of-conduct>`.

If you are becoming a first-time contributor, we recommend starting with:

.. toctree::
   :caption: Getting started
   :maxdepth: 1

   many_ways
   getting_ready
   workflow

After gaining some familiarity with the code contribution workflow, we
suggest checking out:

.. toctree::
   :caption: Contributing to PlasmaPy
   :maxdepth: 2

   coding_guide
   testing_guide
   doc_guide
   changelog_guide
   pre-commit

The contributions are made to |PlasmaPy's GitHub repository|. Thank you
again!
